@@ -18,7 +18,7 @@ IWL::Notebook - a tabbed notebook widget
 
 =head1 INHERITANCE
 
-IWL::Object -> IWL::Widget -> IWL::Container -> IWL::Notebook
+L<IWL::Object> -> L<IWL::Widget> -> L<IWL::Container> -> L<IWL::Notebook>
 
 =head1 DESCRIPTION
 
@@ -50,7 +50,7 @@ sub new {
 
     $self->{_noChildren} = 0;
 
-    # The list of pages
+    # The list of tabs
     $self->{__tabs} = [];
 
     $self->__init(%args);
@@ -68,6 +68,8 @@ Appends a new tab and adds the object to the tab page
 
 Parameter: B<OBJECT> - the IWL::Object(3pm) to be appended, B<TEXT> - the text for the tab label, B<SELECTED> - true if the tab should be the selected one
 
+Returns: the newly created tab 
+
 =cut
 
 sub appendTab {
@@ -81,6 +83,8 @@ Prepends a new tab and adds the object to the tab page
 
 Parameter: B<OBJECT> - the IWL::Object(3pm) to be prepended, B<TEXT> - the text for the tab label, B<SELECTED> - true if the tab should be the selected one
 
+Returns: the newly created tab 
+
 =cut
 
 sub prependTab {
@@ -121,16 +125,13 @@ sub _realize {
 }
 
 sub _registerEvent {
-    my ($self, $event, $params) = @_;
+    my ($self, $event, $params, $options) = @_;
 
-    my $handlers = {};
     if ($event eq 'IWL-Notebook-Tab-add') {
-	return $handlers;
+	return $options;
     } else {
-	$self->SUPER::_registerEvent($event, $params);
+	return $self->SUPER::_registerEvent($event, $params, $options);
     }
-
-    return $handlers;
 }
 
 sub _setupDefaultClass {
@@ -180,13 +181,12 @@ sub __init {
 sub __setup_page {
     my ($self, $object, $text, $selected, $reverse) = @_;
     my $tab = IWL::Notebook::Tab->new;
-    my $index;
 
     $tab->appendPage($object);
     if ($reverse) {
-	$index = unshift @{$self->{__tabs}}, $tab;
+	unshift @{$self->{__tabs}}, $tab;
     } else {
-	$index = push @{$self->{__tabs}}, $tab;
+	push @{$self->{__tabs}}, $tab;
     }
 
     $tab->setSelected($selected) if $object;
