@@ -23,10 +23,10 @@ Object.extend(Object.extend(Menu, Widget), {
             if (this.parentMenu && !this.parentMenu.hasClassName('menubar'))
                 this.parentMenu.setStyle({display: 'block'});
 	    if (this.parentMenu && this.parentMenu.getStyle('position') == 'absolute')
-		paren_position = Position.cumulativeOffset(this.parentItem);
+		paren_position = this.parentItem.cumulativeOffset();
 	    else
-		paren_position = Position.positionedOffset(this.parentItem);
-	    var paren_dimensions = Element.getDimensions(this.parentItem);
+		paren_position = this.parentItem.positionedOffset();
+	    var paren_dimensions = this.parentItem.getDimensions();
 	    if (this.hasClassName('submenu')) {
 		Element.setStyle(this, {left: paren_dimensions.width + 'px'});
 	    } else {
@@ -35,7 +35,7 @@ Object.extend(Object.extend(Menu, Widget), {
 	    }
 	    if (this.options.maxHeight)
 		this.__setupScrolling();
-	    if (ie4) {
+	    if (Prototype.Browser.IE) {
 		var dims = this.getDimensions();
 		this.setStyle({width: dims.width + 'px', height: dims.height + 'px'});
 	    }
@@ -168,10 +168,7 @@ Object.extend(Object.extend(Menu, Widget), {
 	    if (paren === document) break;
 	    paren = paren.up();
 	}
-	Event.observe(this, 'mouseover', function() {
-	    focused_widget = this.id}.bind(this));
-	Event.observe(this, 'click', function() {
-	    focused_widget = this.id}.bind(this));
+        registerFocus(this);
 	Event.observe(window, 'click', function(event) {
 	    if (!Event.checkElement(event, this))
 		this.popDown();
@@ -184,19 +181,20 @@ Object.extend(Object.extend(Menu, Widget), {
     },
     _bindPop: function(event, parentItem) {
 	if (parentItem)
-	    this.parentItem = parentItem;
+	    this.parentItem = $(parentItem);
 	if (this.popped)
 	    this.popDown();
 	else
 	    this.popUp();
+        Event.extend(event);
 	Event.stop(event);
 	return this;
     },
     __removeQuirks: function() {
-	if (!ie4 || ie7) return;
+	if (!Prototype.Browser.IE || Prototype.Browser.IE7) return;
 	if (this.__qframe) return;
 	var dims = Element.getDimensions(this);
-	var qframe = Builder.node('iframe', {
+	var qframe = new Element('iframe', {
 	    src: "javascript: false", className: "qframe",
 	    style: "width: " + dims.width + "px; height: " + dims.height + "px;"
 	});
@@ -214,13 +212,13 @@ Object.extend(Object.extend(Menu, Widget), {
 	if (this.options.maxHeight > parseFloat(height)) return;
 	var new_width = parseInt(width) + 20;
 	this.addClassName('scrolling_menu');
-	if (opera)
-	    this.setStyle({width: new_width + 'px', height: this.options.maxHeight + 'px', 'overflow': 'auto'});
+	if (Prototype.Browser.Opera)
+	    this.setStyle({width: new_width + 'px', height: this.options.maxHeight + 'px', overflow: 'auto'});
 	else
-	    this.setStyle({width: new_width + 'px', height: this.options.maxHeight + 'px', 'overflow-y': 'scroll'});
+	    this.setStyle({width: new_width + 'px', height: this.options.maxHeight + 'px', overflowY: 'scroll'});
     },
     __KeyEventsCB: function(event) {
-	var keyCode = getKeyCode(event);
+	var keyCode = Event.getKeyCode(event);
 	var shift = event.shiftKey;
 	if (focused_widget != this.id)
 	    return;
